@@ -133,7 +133,7 @@ class SchemaMeta(type):
         inherited_fields: typing.List,
         dict_cls: type,
     ):
-        """Returns a dictionary of field_name => `Field` pairs declard on the class.
+        """Returns a dictionary of field_name => `Field` pairs declared on the class.
         This is exposed mainly so that plugins can add additional fields, e.g. fields
         computed from class Meta options.
 
@@ -242,15 +242,18 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
 
         from marshmallow import Schema, fields
 
+
         @dataclass
         class Album:
             title: str
             release_date: dt.date
 
+
         class AlbumSchema(Schema):
             title = fields.Str()
             release_date = fields.Date()
 
+
         album = Album("Beggars Banquet", dt.date(1968, 12, 6))
         schema = AlbumSchema()
         data = schema.dump(album)
@@ -579,7 +582,10 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
 
     def _deserialize(
         self,
-        data: typing.Union[typing.Dict, typing.Iterable],
+        data: typing.Union[
+            typing.Mapping[str, typing.Any],
+            typing.Iterable[typing.Mapping[str, typing.Any]],
+        ],
         *,
         error_store: ErrorStore,
         many: bool = False,
@@ -613,7 +619,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
                     typing.cast(
                         _T,
                         self._deserialize(
-                            d,
+                            typing.cast(typing.Mapping[str, typing.Any], d),
                             error_store=error_store,
                             many=False,
                             partial=partial,
@@ -684,7 +690,10 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
 
     def load(
         self,
-        data: typing.Mapping,
+        data: typing.Union[
+            typing.Mapping[str, typing.Any],
+            typing.Iterable[typing.Mapping[str, typing.Any]],
+        ],
         *,
         many: bool = None,
         partial: typing.Union[bool, types.StrSequenceOrSet] = None,
@@ -797,7 +806,10 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
 
     def _do_load(
         self,
-        data: typing.Mapping,
+        data: typing.Union[
+            typing.Mapping[str, typing.Any],
+            typing.Iterable[typing.Mapping[str, typing.Any]],
+        ],
         *,
         many: bool = None,
         partial: typing.Union[bool, types.StrSequenceOrSet] = None,
